local GuideScreen = require "screens/modguide_screen"

local assets = {
	Asset("ANIM", "anim/books.zip"),
}
local extra_assets = {} --used below

local function Open(inst)
	local guy = inst.components.inventoryitem:GetGrandOwner()
	if guy and guy.HUD then
		TheFrontEnd:PushScreen(GuideScreen(inst))
	end
end

local function OnSave(inst,data)
	data.currentpage = inst.currentpage
end

local function OnLoad(inst,data)
	if data then
		inst.currentpage = data.currentpage
	end
end

local package = {}

local function NextTome(data)
	local function fn()
		local inst = CreateEntity()
		inst.entity:AddTransform()
		inst.entity:AddAnimState()
		inst.entity:AddSoundEmitter()
		
		MakeInventoryPhysics(inst)
		
		inst.AnimState:SetBank(data.custombuild or "books")
		inst.AnimState:SetBuild(data.custombuild or "books")
		inst.AnimState:PlayAnimation(data.anim)
		
		inst:AddComponent("inspectable")
		inst:AddComponent("inventoryitem")
		inst.components.inventoryitem.imagename = data.anim
		if data.custombuild then
			inst.components.inventoryitem.atlasname = "images/".. data.custombuild ..".xml"
		end
		
		inst:AddComponent("useableitem")
		inst.components.useableitem.onusefn = Open
		inst.components.useableitem.caninteractfn = function() return true end --against component limitations
		
		if data.float and IsDLCEnabled(CAPY_DLC) then
			MakeInventoryFloatable(inst, data.anim .."_water", data.anim)
		end
		
		inst.pages = data.pages --the pages themselves
		inst.toc = data.toc --the index page (table of content)
		inst.chapters = data.chapters --whether to lock to chapters
		
		inst:AddTag("book")
		inst:AddTag("guide")
		inst:AddTag("irreplacable")
		
		inst.OnSave = OnSave
		inst.OnLoad = OnLoad
		
		return inst
	end
	
	if data.custombuild then
		extra_assets[data.custombuild] = true
	end
	table.insert(package,Prefab("common/inventory/".. data.prefab,fn,assets))
end

--return Prefab("common/inventory/modguide",fn,assets)
for _,data in pairs(TomesToMake) do
	NextTome(data)
end

for k,v in pairs(extra_assets) do --fix assets table
	table.insert(assets,Asset("ANIM","anim/".. k ..".zip"))
	table.insert(assets,Asset("ATLAS","images/".. k ..".xml"))
	table.insert(assets,Asset("IMAGE","images/".. k ..".tex"))
end

return unpack(package)